/*
 * Copyright (C) 2022 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#include <gtest/gtest.h>

#include "sdf/OutputConfig.hh"
#include "test_config.hh"

/////////////////////////////////////////////////
/// Test default construction of sdf::OutputConfig.
TEST(OutputConfig, Construction)
{
  sdf::OutputConfig config;
  EXPECT_TRUE(config.ToElementUseIncludeTag());

  config.SetToElementUseIncludeTag(false);
  EXPECT_FALSE(config.ToElementUseIncludeTag());
  EXPECT_TRUE(config.GlobalConfig().ToElementUseIncludeTag());

  config.GlobalConfig().SetToElementUseIncludeTag(false);
  EXPECT_FALSE(config.ToElementUseIncludeTag());
  EXPECT_FALSE(config.GlobalConfig().ToElementUseIncludeTag());
}
